# Claude Code Instructions

## Permissions
- Proceed with file reads, edits, writes, searches, and non-destructive shell commands without asking permission.
- Only ask before genuinely destructive or irreversible operations (force push, dropping data, deleting branches).
- When in doubt, just do it.
